@@ -1,9 +1,9 @@
-"""Conductor Auth POST route schemas."""
+"""Blackcap Auth POST route schemas."""
 
 from typing import List
 
-from conductor.schemas.api.common import ResponseSchema
-from conductor.schemas.user import User
+from blackcap.schemas.api.common import ResponseSchema
+from blackcap.schemas.user import User
 
 from pydantic import BaseModel
 
